==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/delegation_links.dart <==
part of keyclic_sdk_api.api;

class DelegationLinks {
  DelegationLinks({
    this.self,
    this.from,
    this.to,
    this.report,
    this.createdBy,
  });

  DelegationLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    self = DelegationLinksSelf.fromJson(json['self']);
    from = DelegationLinksFrom.fromJson(json['from']);
    to = DelegationLinksTo.fromJson(json['to']);
    report = DelegationLinksReport.fromJson(json['report']);
    createdBy = DelegationLinksCreatedBy.fromJson(json['createdBy']);
  }

  DelegationLinksSelf self;

  DelegationLinksFrom from;

  DelegationLinksTo to;

  DelegationLinksReport report;

  DelegationLinksCreatedBy createdBy;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is DelegationLinks && runtimeType == other.runtimeType;
  }

  @override
  int get hashCode => 0;

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'from': from,
      'to': to,
      'report': report,
      'createdBy': createdBy,
    };
  }

  @override
  String toString() {
    return 'DelegationLinks[self=$self, from=$from, to=$to, report=$report, createdBy=$createdBy, ]';
  }

  static List<DelegationLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? List<DelegationLinks>()
        : json.map((value) => DelegationLinks.fromJson(value)).toList();
  }

  static Map<String, DelegationLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, DelegationLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = DelegationLinks.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/delegation_links.dart <==
part of keyclic_sdk_api.api;

class DelegationLinks {
  DelegationLinks({
    this.createdBy,
    this.report,
    this.self,
    this.service,
  });

  DelegationLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    createdBy = DelegationLinksCreatedBy.fromJson(json['createdBy']);
    report = DelegationLinksReport.fromJson(json['report']);
    self = DelegationLinksSelf.fromJson(json['self']);
    service = DelegationLinksService.fromJson(json['service']);
  }

  DelegationLinksCreatedBy createdBy;

  DelegationLinksReport report;

  DelegationLinksSelf self;

  DelegationLinksService service;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is DelegationLinks &&
        runtimeType == other.runtimeType &&
        createdBy == other.createdBy &&
        report == other.report &&
        self == other.self &&
        service == other.service;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^
      createdBy.hashCode ^
      report.hashCode ^
      self.hashCode ^
      service.hashCode;

  static List<DelegationLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? <DelegationLinks>[]
        : json.map((value) => DelegationLinks.fromJson(value)).toList();
  }

  static Map<String, DelegationLinks> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, DelegationLinks>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = DelegationLinks.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'createdBy': createdBy,
      'report': report,
      'self': self,
      'service': service,
    };
  }

  @override
  String toString() {
    return 'DelegationLinks[createdBy=$createdBy, report=$report, self=$self, service=$service, ]';
  }
}
